@@ -20,7 +20,7 @@ from glob import glob
 from kook.utils import read_file, write_file
 
 package   = prop('package', 'Oktest')
-release   = prop('release', '0.14.2')
+release   = prop('release', '0.15.0')
 copyright = prop('copyright', "copyright(c) 2010-2014 kuwata-lab.com all rights reserved")
 license   = "MIT License"
 python    = prop('python', sys.executable)
@@ -44,6 +44,8 @@ python_binaries = [
     ('3.0', '/opt/lang/python/3.0.1/bin/python'),
     ('3.1', '/opt/lang/python/3.1.4/bin/python'),
     ('3.2', '/opt/lang/python/3.2.0/bin/python'),
+    ('3.3', '/opt/lang/python/3.3.3/bin/python'),
+    ('3.4', '/opt/lang/python/3.4.0/bin/python'),
 ]
 
 
@@ -62,7 +64,7 @@ def _with_backup(filepath):
     return deco
 
 
-TEST_NAMES = ('tracer', 'spec', 'testdeco', 'fixture',
+TEST_NAMES = ('tracer', 'spec', 'testdeco', 'fixture', 'options',
               'doc', 'assertions', 'dummy', 'runner', 'context', 'reporter',
               'util', 'skip', 'todo', 'resp', 'mainapp', 'web', 'validator',)
 test_names = [ os.path.basename(x).replace('_test.py', '')
@@ -71,7 +73,7 @@ assert set(TEST_NAMES) == set(test_names)
 
 
 @recipe
-@spices("-a: do with python from 2.4 to 3.2", "[testnames...]")
+@spices("-a: do with python from 2.4 to 3.4", "[testnames...]")
 def task_test(c, *args, **kwargs):
     """do test by oktest"""
     #optstr = " -m oktest"
@@ -85,7 +87,7 @@ def task_test(c, *args, **kwargs):
 
 @recipe
 @ingreds('test/doc_test.py')
-@spices("-a: do with python from 2.4 to 3.2", "[testnames...]")
+@spices("-a: do with python from 2.4 to 3.4", "[testnames...]")
 def task_unittest(c, *args, **kwargs):
     """do test by unittest module"""
     flag_all = bool(kwargs.get('a'))
