@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ###
-### $Release: 0.14.2 $
+### $Release: 0.15.0 $
 ### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -93,7 +93,7 @@ class TestDeco_TC(unittest.TestCase):
         except:
             ex_class, ex = sys.exc_info()[:2]
             self.fail("Nothing should be raised but got %s: %s" % (ex_class.__name__, ex))
-        self.assertEqual({'tag': "test"}, test_foo._tags)
+        self.assertEqual({'tag': "test"}, test_foo._options)
 
     @test("not to override existing document of function.")
     def t(self):
@@ -113,8 +113,8 @@ class TestDeco_TC(unittest.TestCase):
         @test("[!abc123_-] description", tag='hom')
         def _(self):
             pass
-        self.assertEqual(_._tags, {'sid': 'abc123_-', 'tag': 'hom'})
-        self.assertEqual(self._tags, {'sid': 'xyz', 'tag': 'abc'})
+        self.assertEqual(_._options, {'sid': 'abc123_-', 'tag': 'hom'})
+        self.assertEqual(self._options, {'sid': 'xyz', 'tag': 'abc'})
 
     @test("日本語文字列をサポート")
     def _(self):
@@ -134,16 +134,16 @@ class TestDeco_TC(unittest.TestCase):
 
 
     ##
-    ## test tags
+    ## test options
     ##
 
-    @test("set tags to test object", name="Haruhi", team="SOS")
+    @test("set options to test object", name="Haruhi", team="SOS")
     def t(self):
-        assert self._tags == {"name": "Haruhi", "team": "SOS"}
+        assert self._options == {"name": "Haruhi", "team": "SOS"}
 
-    @test("set tags even when fixtures are supplied", name="Sasaki", team="Tengai")
+    @test("set options even when fixtures are supplied", name="Sasaki", team="Tengai")
     def t(self, item1):
-        assert self._tags == {"name": "Sasaki", "team": "Tengai"}
+        assert self._options == {"name": "Sasaki", "team": "Tengai"}
 
     def provide_item1(self):
         return {"key": "ITEM1"}
