@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ###
-### $Release: 0.14.2 $
+### $Release: 0.15.0 $
 ### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -15,7 +15,7 @@ import unittest
 import oktest
 from oktest import ok, NG, run
 from oktest import python2, python3
-from oktest.util import chdir, flatten, rm_rf, from_here, randstr, zenkaku_width, zenkaku_shorten
+from oktest.util import chdir, flatten, rm_rf, repr_rexp, from_here, randstr, zenkaku_width, zenkaku_shorten
 
 
 available_with_statement = sys.version_info[0:2] > (2, 4)
@@ -244,6 +244,15 @@ class util_TC(unittest.TestCase):
             self._after_rm_rf()
 
 
+    def test_repr_rexp_1(self):
+        x = repr_rexp(re.compile('\w{40}'))
+        ok (x) == r"re.compile(r'\w{40}')"
+
+    def test_repr_rexp_2(self):
+        x = repr_rexp(re.compile('\w{40}', re.I|re.S|re.M))
+        ok (x) == r"re.compile(r'\w{40}', re.I|re.M|re.S)"
+
+
     def test_from_here_1(self):
         old = sys.path[:]
         currpath = os.path.join(os.getcwd(), os.path.dirname(__file__), 'foobar')
